@@ -35,13 +35,13 @@ MAX_TRANSACTION_COUNT = 2000
 # K线数据最多800条
 MAX_KLINE_COUNT = 800
 
-FREQUENCY = ["5m", "15m", "30m", "1h", "day", "week", "mon", "ex_1m", "1m", "dk", "3mon", "year"]
+FREQUENCY = ['5m', '15m', '30m', '1h', 'day', 'week', 'mon', 'ex_1m', '1m', 'dk', '3mon', 'year']
 
 # 板块相关参数
-BLOCK_SZ = "block_zs.dat"
-BLOCK_FG = "block_fg.dat"
-BLOCK_GN = "block_gn.dat"
-BLOCK_DEFAULT = "block.dat"
+BLOCK_SZ = 'block_zs.dat'
+BLOCK_FG = 'block_fg.dat'
+BLOCK_GN = 'block_gn.dat'
+BLOCK_DEFAULT = 'block.dat'
 
 TYPE_FLATS = 0
 TYPE_GROUP = 1
@@ -88,25 +88,25 @@ HQ_HOSTS = [
 ]
 
 EX_HOSTS = [
-    ("扩展市场深圳双线1", "112.74.214.43", 7727),
-    ("扩展市场深圳双线2", "120.24.0.77", 7727),
-    ("扩展市场深圳双线3", "47.107.75.159", 7727),
-    ("扩展市场武汉主站1", "119.97.185.5", 7727),
-    ("扩展市场武汉主站2", "202.103.36.71", 7727),
-    ("扩展市场武汉主站3", "59.175.238.38", 7727),
-    ("扩展市场北京双线0", "47.92.127.181", 7727),
-    ("扩展市场上海双线0", "106.14.95.149", 7727),
-    ("扩展市场新加双线0", "119.23.127.172", 7727),
+    ('扩展市场深圳双线1', '112.74.214.43', 7727),
+    ('扩展市场深圳双线2', '120.24.0.77', 7727),
+    ('扩展市场深圳双线3', '47.107.75.159', 7727),
+    ('扩展市场武汉主站1', '119.97.185.5', 7727),
+    ('扩展市场武汉主站2', '202.103.36.71', 7727),
+    ('扩展市场武汉主站3', '59.175.238.38', 7727),
+    ('扩展市场北京双线0', '47.92.127.181', 7727),
+    ('扩展市场上海双线0', '106.14.95.149', 7727),
+    ('扩展市场新加双线0', '119.23.127.172', 7727),
 ]
 
 GP_HOSTS = [
-    ("默认财务数据线路", "120.76.152.87", 7709),
+    ('默认财务数据线路', '120.76.152.87', 7709),
 ]
 
 CONFIG = {
-    "SERVER": {"HQ": HQ_HOSTS, "EX": EX_HOSTS, "GP": GP_HOSTS},
-    "BESTIP": {"HQ": "", "EX": "", "GP": ""},
-    "TDXDIR": "C:/new_tdx",
+    'SERVER': {'HQ': HQ_HOSTS, 'EX': EX_HOSTS, 'GP': GP_HOSTS},
+    'BESTIP': {'HQ': '', 'EX': '', 'GP': ''},
+    'TDXDIR': 'C:/new_tdx',
 }
 
 
