@@ -1,16 +1,17 @@
 import os
-import pandas as pd
 import secrets
 import shutil
 import tempfile
 from pathlib import Path
-from tdxpy.hq import TdxHq_API
 from struct import calcsize
 from struct import unpack
 
+import pandas as pd
+from tdxpy.hq import TdxHq_API
+
+from ..logger import logger
 from .base import BaseFinancial
 from .columns import columns
-from ..logger import logger
 
 
 class FinancialReader(object):
@@ -27,7 +28,7 @@ class FinancialReader(object):
 
         crawler = Financial()
 
-        with open(filename, "rb") as fp:
+        with open(filename, 'rb') as fp:
             data = crawler.parse(download_file=fp)
 
         return crawler.to_df(data, **kwargs)
@@ -53,8 +54,8 @@ class FinancialList(BaseFinancial):
         api.need_setup = False
 
         with api.connect(*self.bestip):
-            content = api.get_report_file_by_size("tdxfin/gpcw.txt")
-            download_file = open(downdir, "wb") if downdir else tmp
+            content = api.get_report_file_by_size('tdxfin/gpcw.txt')
+            download_file = open(downdir, 'wb') if downdir else tmp
             download_file.write(content)
             download_file.seek(0)
 
@@ -72,14 +73,14 @@ class FinancialList(BaseFinancial):
 
         with download_file:
             content = download_file.read()
-            content = content.decode("utf-8")
+            content = content.decode('utf-8')
 
         def l2d(i):
-            return {"filename": i[0], "hash": i[1], "filesize": int(i[2])}
+            return {'filename': i[0], 'hash': i[1], 'filesize': int(i[2])}
 
         if content:
-            content = content.strip().split("\n")
-            return [l2d(i) for i in [line.strip().split(",") for line in content]]
+            content = content.strip().split('\n')
+            return [l2d(i) for i in [line.strip().split(',') for line in content]]
 
         return None
 
@@ -98,27 +99,27 @@ class Financial(BaseFinancial):
         :return:
         """
 
-        filename = kwargs.get("filename")
+        filename = kwargs.get('filename')
         downfile = str(Path(downdir) / filename)
-        filesize = kwargs.get("filesize") if kwargs.get("filesize") else 0
+        filesize = kwargs.get('filesize') if kwargs.get('filesize') else 0
 
-        logger.debug(f"{filename}: start download...")
+        logger.debug(f'{filename}: start download...')
 
         if not filename:
-            raise Exception("Param filename is not set")
+            raise Exception('Param filename is not set')
 
         api = TdxHq_API()
         api.need_setup = False
 
         with api.connect(*self.bestip):
-            content = api.get_report_file_by_size(f"tdxfin/{filename}", filesize=filesize, reporthook=report_hook)
-            download_file = downfile and open(downfile, "wb") or tempfile.NamedTemporaryFile(delete=True)
+            content = api.get_report_file_by_size(f'tdxfin/{filename}', filesize=filesize, reporthook=report_hook)
+            download_file = downfile and open(downfile, 'wb') or tempfile.NamedTemporaryFile(delete=True)
             download_file.write(content)
             download_file.seek(0)
 
             del content
 
-            logger.debug(f"{filename}: done")
+            logger.debug(f'{filename}: done')
 
             return download_file
 
@@ -132,12 +133,12 @@ class Financial(BaseFinancial):
         :return:
         """
 
-        header_pack_format = "<1hI1H3L"
+        header_pack_format = '<1hI1H3L'
         tmpdir = tempfile.gettempdir()
 
-        if download_file.name.endswith(".zip"):
+        if download_file.name.endswith('.zip'):
             tmpdir_root = tempfile.gettempdir()
-            subdir_name = f"mootdx_{secrets.randbelow(1000000)}"
+            subdir_name = f'mootdx_{secrets.randbelow(1000000)}'
 
             tmpdir = Path(tmpdir_root, subdir_name)
             shutil.rmtree(tmpdir, ignore_errors=True)
@@ -149,19 +150,19 @@ class Financial(BaseFinancial):
             dat_file = None
 
             for _file in os.listdir(tmpdir):
-                if str(_file).endswith(".dat"):
-                    dat_file = open(Path(tmpdir, str(_file)), "rb")
+                if str(_file).endswith('.dat'):
+                    dat_file = open(Path(tmpdir, str(_file)), 'rb')
 
             if dat_file is None:
-                raise Exception("no dat file found in zip archive")
+                raise Exception('no dat file found in zip archive')
 
-        elif download_file.name.endswith(".dat"):
+        elif download_file.name.endswith('.dat'):
             dat_file = download_file
         else:
             return None
 
         header_size = calcsize(header_pack_format)
-        stock_item_size = calcsize("<6s1c1L")
+        stock_item_size = calcsize('<6s1c1L')
 
         data_header = dat_file.read(header_size)
         stock_header = unpack(header_pack_format, data_header)
@@ -172,15 +173,15 @@ class Financial(BaseFinancial):
         report_size = stock_header[4]
 
         report_fields_count = int(report_size / 4)
-        report_pack_format = "<{}f".format(report_fields_count)
+        report_pack_format = '<{}f'.format(report_fields_count)
 
         results = []
 
         for stock_idx in range(0, max_count):
-            dat_file.seek(header_size + stock_idx * calcsize("<6s1c1L"))
+            dat_file.seek(header_size + stock_idx * calcsize('<6s1c1L'))
             si = dat_file.read(stock_item_size)
-            stock_item = unpack("<6s1c1L", si)
-            code = stock_item[0].decode("utf-8")
+            stock_item = unpack('<6s1c1L', si)
+            code = stock_item[0].decode('utf-8')
             dat_file.seek(stock_item[2])
 
             info_data = dat_file.read(calcsize(report_pack_format))
@@ -188,7 +189,7 @@ class Financial(BaseFinancial):
             one_record = (code, report_date) + cw_info
             results.append(one_record)
 
-        if download_file.name.endswith(".zip"):
+        if download_file.name.endswith('.zip'):
             dat_file.close()
             shutil.rmtree(tmpdir, ignore_errors=True)
 
@@ -197,7 +198,7 @@ class Financial(BaseFinancial):
         return results
 
     @staticmethod
-    def to_df(data, header="zh"):
+    def to_df(data, header='zh'):
         """
         转换数据为 pandas DataFrame 格式
 
@@ -209,15 +210,15 @@ class Financial(BaseFinancial):
         if len(data) == 0 or len(data[0]) == 0:
             return pd.DataFrame(data=None)
 
-        column = ["code", "report_date"]
+        column = ['code', 'report_date']
 
         for i in range(1, len(data[0]) - 1):
-            column.append("col" + str(i))
+            column.append('col' + str(i))
 
         df = pd.DataFrame(data=data, columns=column)
-        df.set_index("code", inplace=True)
+        df.set_index('code', inplace=True)
 
-        if header == "zh":
+        if header == 'zh':
             df.columns = columns
 
         logger.debug(df.shape)
