@@ -1,4 +1,5 @@
 import math
+from datetime import datetime
 
 import pandas
 import pandas as pd
@@ -25,7 +26,7 @@ from mootdx.utils import to_data
 
 class Quotes(object):
     @staticmethod
-    def factory(market="std", **kwargs):
+    def factory(market='std', **kwargs):
         """
         股票市场 工厂方法
 
@@ -36,7 +37,7 @@ class Quotes(object):
 
         logger.debug(kwargs)
 
-        if market == "ext":
+        if market == 'ext':
             return ExtQuotes(**kwargs)
 
         return StdQuotes(**kwargs)
@@ -63,34 +64,34 @@ class BaseQuotes(object):
 
     def __init__(self, server=None, bestip: bool = False, timeout: int = None, **kwargs) -> None:
 
-        logger.debug(f"server => {server}")
+        logger.debug(f'server => {server}')
         self.server = valid_server(server)
 
-        logger.debug(f"bestip => {bestip}")
-        (bestip or (not config.get("BESTIP"))) and check_server(sync=False)
+        logger.debug(f'bestip => {bestip}')
+        (bestip or (not config.get('BESTIP'))) and check_server(sync=False)
 
-        logger.debug(f"timeout => {timeout}")
+        logger.debug(f'timeout => {timeout}')
         self.timeout = timeout if timeout else 15
 
-        logger.debug("config.setup()")
+        logger.debug('config.setup()')
         config.setup()
 
     def __del__(self):
-        logger.debug("call __del__")
+        logger.debug('call __del__')
         self.close()
 
     def reconnect(self):
         if self.closed:
-            logger.debug("服务器连接已断开，正进行重新连接...")
+            logger.debug('服务器连接已断开，正进行重新连接...')
             self.client.connect(*self.bestip)
 
     def close(self):
-        logger.debug("close")
-        hasattr(self.client, "close") and self.client.close()
+        logger.debug('close')
+        hasattr(self.client, 'close') and self.client.close()
 
     @property
     def closed(self) -> bool:
-        if not hasattr(self.client.client, "_closed") or getattr(self.client.client, "_closed"):
+        if not hasattr(self.client.client, '_closed') or getattr(self.client.client, '_closed'):
             return True
 
         return False
@@ -113,7 +114,7 @@ def check_empty(value):
 
     # 判断状态空，则重连接
     if instance and _empty:
-        logger.warning("返回数据空, 重新连接服务器...")
+        logger.warning('返回数据空, 重新连接服务器...')
         # instance.client.connect(*instance.server)
 
     return _empty
@@ -132,21 +133,21 @@ class StdQuotes(BaseQuotes):
         """
 
         super().__init__(bestip=bestip, timeout=timeout, server=server, **kwargs)
-        self.server and config.set("BESTIP", {"HQ": self.server})
+        self.server and config.set('BESTIP', {'HQ': self.server})
 
         try:
-            config.get("SERVER").get("HQ")[0]
+            config.get('SERVER').get('HQ')[0]
         except ValueError as ex:
             logger.warning(ex)
         finally:
-            default = config.get("SERVER").get("HQ")[0][1:]
-            self.server = config.get("BESTIP").get("HQ", default)
+            default = config.get('SERVER').get('HQ')[0][1:]
+            self.server = config.get('BESTIP').get('HQ', default)
 
-        for x in ["verbose", "server", "quiet", "heartbeat", "multithread", "auto_retry"]:
+        for x in ['verbose', 'server', 'quiet', 'heartbeat', 'multithread', 'auto_retry']:
             if x in kwargs.keys():
                 del kwargs[x]
 
-        logger.debug(f"server: {self.server}")
+        logger.debug(f'server: {self.server}')
         ip, port = self.server
 
         self.client = TdxHq_API(heartbeat=False, auto_retry=True, raise_exception=False, **kwargs)
@@ -195,7 +196,7 @@ class StdQuotes(BaseQuotes):
     #     retry_error_callback=return_last_value,
     #     retry=(retry_if_exception_type() | retry_if_result(check_empty)),
     # )
-    def bars(self, symbol="000001", frequency=9, start=0, offset=100, **kwargs):
+    def bars(self, symbol='000001', frequency=9, start=0, offset=100, **kwargs):
         """
         获取实时日K线数据
 
@@ -226,7 +227,7 @@ class StdQuotes(BaseQuotes):
         :return: pd.dataFrame or None
         """
         if market not in [0, 1, 2]:
-            raise MootdxValidationException("市场代码错误")
+            raise MootdxValidationException('市场代码错误')
 
         result = self.client.get_security_count(market=market)
 
@@ -247,7 +248,7 @@ class StdQuotes(BaseQuotes):
         """
 
         if market not in [0, 1]:
-            raise MootdxValidationException("市场代码错误, 目前只支持沪深市场")
+            raise MootdxValidationException('市场代码错误, 目前只支持沪深市场')
 
         counts = self.stock_count(market=market)
         stocks = None
@@ -265,7 +266,7 @@ class StdQuotes(BaseQuotes):
     #     retry_error_callback=return_last_value,
     #     retry=(retry_if_exception_type() | retry_if_result(check_empty)),
     # )
-    def index_bars(self, symbol="000001", frequency=9, start=0, offset=100, **kwargs):
+    def index_bars(self, symbol='000001', frequency=9, start=0, offset=100, **kwargs):
         """
         获取指数k线
 
@@ -289,7 +290,7 @@ class StdQuotes(BaseQuotes):
     #     retry_error_callback=return_last_value,
     #     retry=(retry_if_exception_type() | retry_if_result(check_empty)),
     # )
-    def minute(self, symbol="", **kwargs):
+    def minute(self, symbol=None, **kwargs):
         """
         获取实时分时数据
 
@@ -297,10 +298,8 @@ class StdQuotes(BaseQuotes):
         :return: pd.DataFrame
         """
 
-        market = get_stock_market(symbol)
-        result = self.client.get_minute_time_data(market=market, code=symbol)
-
-        return to_data(result, symbol=symbol, client=self, **kwargs)
+        today = datetime.now().strftime('%Y%m%d')
+        return self.minutes(symbol=symbol, date=today, **kwargs)
 
     # @retry(
     #     wait=wait_random(min=1, max=10),
@@ -308,7 +307,7 @@ class StdQuotes(BaseQuotes):
     #     retry_error_callback=return_last_value,
     #     retry=(retry_if_exception_type() | retry_if_result(check_empty)),
     # )
-    def minutes(self, symbol="", date="20191023", **kwargs):
+    def minutes(self, symbol=None, date='20191023', **kwargs):
         """
         分时历史数据
 
@@ -320,7 +319,7 @@ class StdQuotes(BaseQuotes):
         market = get_stock_market(symbol)
 
         if market not in [0, 1]:
-            raise MootdxValidationException("市场代码错误, 目前只支持沪深市场")
+            raise MootdxValidationException('市场代码错误, 目前只支持沪深市场')
 
         result = self.client.get_history_minute_time_data(market=market, code=symbol, date=date)
 
@@ -332,7 +331,7 @@ class StdQuotes(BaseQuotes):
     #     retry_error_callback=return_last_value,
     #     retry=(retry_if_exception_type() | retry_if_result(check_empty)),
     # )
-    def transaction(self, symbol="", start=0, offset=10, **kwargs):
+    def transaction(self, symbol='', start=0, offset=10, **kwargs):
         """
         查询分笔成交
 
@@ -343,6 +342,7 @@ class StdQuotes(BaseQuotes):
         """
 
         market = get_stock_market(symbol)
+
         result = self.client.get_transaction_data(int(market), symbol, start, offset)
 
         return to_data(result, symbol=symbol, client=self, **kwargs)
@@ -353,7 +353,7 @@ class StdQuotes(BaseQuotes):
     #     retry_error_callback=return_last_value,
     #     retry=(retry_if_exception_type() | retry_if_result(check_empty)),
     # )
-    def transactions(self, symbol="", start=0, offset=10, date="20170209", **kwargs):
+    def transactions(self, symbol='', start=0, offset=10, date='20170209', **kwargs):
         """
         查询历史分笔成交
 
@@ -367,7 +367,7 @@ class StdQuotes(BaseQuotes):
         market = get_stock_market(symbol, string=False)
 
         if market not in [0, 1]:
-            raise MootdxValidationException("市场代码错误, 目前只支持沪深市场")
+            raise MootdxValidationException('市场代码错误, 目前只支持沪深市场')
 
         result = self.client.get_history_transaction_data(
             market=market, code=symbol, start=start, count=offset, date=int(date)
@@ -381,7 +381,7 @@ class StdQuotes(BaseQuotes):
     #     retry_error_callback=return_last_value,
     #     retry=(retry_if_exception_type() | retry_if_result(check_empty)),
     # )
-    def F10C(self, symbol=""):  # noqa
+    def F10C(self, symbol=''):  # noqa
         """
         查询公司信息目录
 
@@ -392,7 +392,7 @@ class StdQuotes(BaseQuotes):
         market = int(get_stock_market(symbol))
 
         if market not in [0, 1]:
-            raise MootdxValidationException("市场代码错误, 目前只支持沪深市场")
+            raise MootdxValidationException('市场代码错误, 目前只支持沪深市场')
 
         result = self.client.get_company_info_category(market, symbol)
 
@@ -404,7 +404,7 @@ class StdQuotes(BaseQuotes):
     #     retry_error_callback=return_last_value,
     #     retry=(retry_if_exception_type() | retry_if_result(check_empty)),
     # )
-    def F10(self, symbol="", name=""):  # noqa
+    def F10(self, symbol='', name=''):  # noqa
         """
         读取公司信息详情
 
@@ -417,7 +417,7 @@ class StdQuotes(BaseQuotes):
         market = int(get_stock_market(symbol, string=False))
 
         if market not in [0, 1]:
-            raise MootdxValidationException("市场代码错误, 目前只支持沪深市场")
+            raise MootdxValidationException('市场代码错误, 目前只支持沪深市场')
 
         category = self.client.get_company_info_category(market, symbol)
 
@@ -426,18 +426,18 @@ class StdQuotes(BaseQuotes):
 
         if name:
             for x in category:
-                if x["name"] == name:
+                if x['name'] == name:
                     return self.client.get_company_info_content(
                         market=market,
                         code=symbol,
-                        filename=x["filename"],
-                        start=x["start"],
-                        length=x["length"],
+                        filename=x['filename'],
+                        start=x['start'],
+                        length=x['length'],
                     )
 
         for x in category:
-            result[x["name"]] = self.client.get_company_info_content(
-                market=market, code=symbol, filename=x["filename"], start=x["start"], length=x["length"]
+            result[x['name']] = self.client.get_company_info_content(
+                market=market, code=symbol, filename=x['filename'], start=x['start'], length=x['length']
             )
 
         return result
@@ -448,7 +448,7 @@ class StdQuotes(BaseQuotes):
     #     retry_error_callback=return_last_value,
     #     retry=(retry_if_exception_type() | retry_if_result(check_empty)),
     # )
-    def xdxr(self, symbol="", **kwargs):
+    def xdxr(self, symbol='', **kwargs):
         """
         读取除权除息信息
 
@@ -467,7 +467,7 @@ class StdQuotes(BaseQuotes):
     #     retry_error_callback=return_last_value,
     #     retry=(retry_if_exception_type() | retry_if_result(check_empty)),
     # )
-    def finance(self, symbol="000001", **kwargs):
+    def finance(self, symbol='000001', **kwargs):
         """
         读取财务信息
 
@@ -480,13 +480,7 @@ class StdQuotes(BaseQuotes):
 
         return to_data(result, symbol=symbol, client=self, **kwargs)
 
-    # @retry(
-    #     wait=wait_random(min=1, max=10),
-    #     stop=stop_after_attempt(3),
-    #     retry_error_callback=return_last_value,
-    #     retry=(retry_if_exception_type() | retry_if_result(check_empty)),
-    # )
-    def k(self, symbol="", begin=None, end=None):
+    def k(self, symbol='', begin=None, end=None, **kwargs):
         """
         读取k线信息
 
@@ -497,25 +491,34 @@ class StdQuotes(BaseQuotes):
         """
 
         result = self.get_k_data(symbol, begin, end)
-        return result
+        return to_data(result, symbol=symbol, **kwargs)
 
     def ohlc(self, **kwargs):
         return self.k(**kwargs)
 
     def get_k_data(self, code, start_date, end_date):
-
         # !! todo
-        data = pd.concat(
-            [
-                self.client.to_df(self.client.get_security_bars(9, get_stock_market(code), code, (9 - i) * 800, 800))
-                for i in range(10)
-            ],
-            axis=0,
-        )
-        data = data.assign(date=data["datetime"].apply(lambda x: str(x)[0:10])).assign(code=str(code))
-        data = data.set_index("date", drop=False, inplace=False)
-        data = data.drop(["year", "month", "day", "hour", "minute", "datetime"], axis=1)[start_date:end_date]
-        data = data.assign(date=data["date"].apply(lambda x: str(x)[0:10]))
+        first = (pd.to_datetime(end_date) - pd.to_datetime(datetime.now().date())).days
+        first = (abs(first), 0)[first >= 0]
+
+        last = (pd.to_datetime(start_date) - pd.to_datetime(datetime.now().date())).days
+        last = (abs(last), 0)[last >= 0]
+
+        first -= int(first / 2.8)  # 非交易日大概是全年的1/3
+        last -= int(last / 3.5)  # 非交易日大概是全年的1/3
+
+        temp = []
+
+        for i in range(math.ceil((last - first) / 800)):
+            temp.append(self.client.to_df(
+                self.client.get_security_bars(9, get_stock_market(code), code, (first + i * 800), 800)))
+
+        data = pd.concat(temp)
+        data = data.assign(date=data['datetime'].apply(lambda x: str(x)[0:10])).assign(code=str(code))
+        data = data.set_index('date', drop=False, inplace=False)
+        data = data.drop(['year', 'month', 'day', 'hour', 'minute', 'datetime'], axis=1)
+        data = data.loc[(data.date >= start_date) & (data.date < end_date)]
+        data = data.sort_index()
 
         return data
 
@@ -525,7 +528,7 @@ class StdQuotes(BaseQuotes):
     #     retry_error_callback=return_last_value,
     #     retry=(retry_if_exception_type() | retry_if_result(check_empty)),
     # )
-    def index(self, symbol="000001", market=MARKET_SH, frequency=9, start=1, offset=2, **kwargs):
+    def index(self, symbol='000001', market=MARKET_SH, frequency=9, start=1, offset=2, **kwargs):
         """
         获取指数k线
 
@@ -561,7 +564,7 @@ class StdQuotes(BaseQuotes):
     #     retry_error_callback=return_last_value,
     #     retry=(retry_if_exception_type() | retry_if_result(check_empty)),
     # )
-    def block(self, tofile="block.dat", **kwargs):
+    def block(self, tofile='block.dat', **kwargs):
         """
         获取证券板块信息
 
@@ -587,26 +590,26 @@ class ExtQuotes(BaseQuotes):
         :param kwargs:  可变参数
         """
         super().__init__(bestip=bestip, timeout=timeout, server=server, **kwargs)
-        self.server and config.set("BESTIP", {"EX": self.server})
+        self.server and config.set('BESTIP', {'EX': self.server})
 
-        logger.warning("目前扩展市场行情接口已经失效, 后期有望修复.")
+        logger.warning('目前扩展市场行情接口已经失效, 后期有望修复.')
 
         try:
-            config.get("SERVER").get("EX")[0]
+            config.get('SERVER').get('EX')[0]
         except ValueError as ex:
             logger.warning(ex)
         finally:
-            default = config.get("SERVER").get("EX")[0]
-            self.server = config.get("BESTIP").get("EX", default)
+            default = config.get('SERVER').get('EX')[0]
+            self.server = config.get('BESTIP').get('EX', default)
 
-        for x in ["verbose", "server", "quiet"]:
+        for x in ['verbose', 'server', 'quiet']:
             if x in kwargs.keys():
                 del kwargs[x]
 
         try:
             self.client = TdxExHq_API(raise_exception=False, auto_retry=True, **kwargs)
             self.client.connect(*self.server)
-        except Exception:
+        except Exception:  # noqa
             logger.error('服务器连接超时.')
 
         global instance
@@ -623,12 +626,12 @@ class ExtQuotes(BaseQuotes):
         """
 
         if not market:
-            if len(symbol.split("#")) > 1:
-                market = symbol.split("#")[0]
-                symbol = symbol.split("#")[1]
+            if len(symbol.split('#')) > 1:
+                market = symbol.split('#')[0]
+                symbol = symbol.split('#')[1]
 
         if not market:
-            raise ValueError("市场参数错误, 市场参数不能为空.")
+            raise ValueError('市场参数错误, 市场参数不能为空.')
 
         return int(market), symbol
 
@@ -712,7 +715,7 @@ class ExtQuotes(BaseQuotes):
         retry_error_callback=return_last_value,
         retry=(retry_if_exception_type() | retry_if_result(check_empty)),
     )
-    def quote(self, market="", symbol="", **kwargs):
+    def quote(self, market='', symbol='', **kwargs):
         """
         查询五档行情
 
@@ -732,7 +735,7 @@ class ExtQuotes(BaseQuotes):
         retry_error_callback=return_last_value,
         retry=(retry_if_exception_type() | retry_if_result(check_empty)),
     )
-    def minute(self, market="", symbol="", **kwargs):
+    def minute(self, market='', symbol='', **kwargs):
         """
         查询分时行情
 
@@ -752,7 +755,7 @@ class ExtQuotes(BaseQuotes):
         retry_error_callback=return_last_value,
         retry=(retry_if_exception_type() | retry_if_result(check_empty)),
     )
-    def minutes(self, market=None, symbol="", date="", **kwargs):
+    def minutes(self, market=None, symbol='', date='', **kwargs):
         """
         查询历史分时行情
 
@@ -773,7 +776,7 @@ class ExtQuotes(BaseQuotes):
         retry_error_callback=return_last_value,
         retry=(retry_if_exception_type() | retry_if_result(check_empty)),
     )
-    def bars(self, frequency="", market="", symbol="", start=0, offset=100, **kwargs):
+    def bars(self, frequency='', market='', symbol='', start=0, offset=100, **kwargs):
         """
         查询k线数据
 
@@ -799,7 +802,7 @@ class ExtQuotes(BaseQuotes):
         retry_error_callback=return_last_value,
         retry=(retry_if_exception_type() | retry_if_result(check_empty)),
     )
-    def transaction(self, market=None, symbol="", start=0, offset=1800, **kwargs):
+    def transaction(self, market=None, symbol='', start=0, offset=1800, **kwargs):
         """
         查询分笔成交
 
@@ -821,7 +824,7 @@ class ExtQuotes(BaseQuotes):
         retry_error_callback=return_last_value,
         retry=(retry_if_exception_type() | retry_if_result(check_empty)),
     )
-    def transactions(self, market=None, symbol="", date="", start=0, offset=1800, **kwargs):
+    def transactions(self, market=None, symbol='', date='', start=0, offset=1800, **kwargs):
         """
         查询历史分笔成交
 
