@@ -17,13 +17,11 @@ from mootdx.logger import logger
 from mootdx.utils import get_config_path
 
 hosts = {
-    "HQ": [{"addr": hs[1], "port": hs[2], "time": 0, "site": hs[0]} for hs in hq_hosts + HQ_HOSTS],
-    "EX": [{"addr": hs[1], "port": hs[2], "time": 0, "site": hs[0]} for hs in EX_HOSTS],
-    "GP": [{"addr": hs[1], "port": hs[2], "time": 0, "site": hs[0]} for hs in GP_HOSTS],
+    'HQ': [{'addr': hs[1], 'port': hs[2], 'time': 0, 'site': hs[0]} for hs in hq_hosts + HQ_HOSTS],
+    'EX': [{'addr': hs[1], 'port': hs[2], 'time': 0, 'site': hs[0]} for hs in EX_HOSTS],
+    'GP': [{'addr': hs[1], 'port': hs[2], 'time': 0, 'site': hs[0]} for hs in GP_HOSTS],
 }
 
-
-
 results = {k: [] for k in hosts}
 
 
@@ -36,7 +34,7 @@ def callback(res, key):
     """
     result = res.result()
 
-    if result.get("time"):
+    if result.get('time'):
         results[key].append(result)
 
     # logger.debug(f"callback: {res.result()}")
@@ -55,18 +53,18 @@ def connect(proxy: dict) -> dict:
 
         start = time.perf_counter()
 
-        sock.connect((proxy.get("addr"), int(proxy.get("port"))))
+        sock.connect((proxy.get('addr'), int(proxy.get('port'))))
         sock.close()
 
-        proxy["time"] = (time.perf_counter() - start) * 1000
+        proxy['time'] = (time.perf_counter() - start) * 1000
 
-        logger.debug("{addr}:{port} 验证通过，响应时间：{time} ms.".format(**proxy))
-    except socket.timeout as ex:
-        logger.debug("{addr},{port} time out.".format(**proxy))
-        proxy["time"] = None
-    except ConnectionRefusedError as ex:
-        logger.debug("{addr},{port} 验证失败.".format(**proxy))
-        proxy["time"] = None
+        logger.debug('{addr}:{port} 验证通过，响应时间：{time} ms.'.format(**proxy))
+    except socket.timeout as ex:  # noqa
+        logger.debug('{addr},{port} time out.'.format(**proxy))
+        proxy['time'] = None
+    except ConnectionRefusedError as ex:  # noqa
+        logger.debug('{addr},{port} 验证失败.'.format(**proxy))
+        proxy['time'] = None
 
     return proxy
 
@@ -78,21 +76,21 @@ def connect2(proxy, index='HQ'):
     api = (TdxHq_API(), TdxExHq_API())[index != 'HQ']
     fun = ('get_security_count', 'get_instrument_count')[index != 'HQ']
 
-    proxy["time"] = None
+    proxy['time'] = None
 
     try:
-        with api.connect(proxy.get("addr"), int(proxy.get("port")), time_out=0.7):
+        with api.connect(proxy.get('addr'), int(proxy.get('port')), time_out=0.7):
             tms = time.perf_counter()
             if getattr(api, fun)():
-                proxy["time"] = (time.perf_counter() - tms) * 1000
-                logger.debug("{addr}:{port} 验证通过，响应时间：{time} ms.".format(**proxy))
+                proxy['time'] = (time.perf_counter() - tms) * 1000
+                logger.debug('{addr}:{port} 验证通过，响应时间：{time} ms.'.format(**proxy))
             else:
-                logger.debug("{addr}:{port} 验证失败.".format(**proxy))
-    except socket.timeout as ex:
-        logger.debug("{addr}:{port} time out.".format(**proxy))
-        proxy["time"] = None
-    except Exception as e:
-        logger.debug("{addr}:{port} 验证失败.".format(**proxy))
+                logger.debug('{addr}:{port} 验证失败.'.format(**proxy))
+    except socket.timeout:  # noqa
+        logger.debug('{addr}:{port} time out.'.format(**proxy))
+        proxy['time'] = None
+    except Exception:  # noqa
+        logger.debug('{addr}:{port} 验证失败.'.format(**proxy))
 
     return proxy
 
@@ -101,6 +99,7 @@ async def verify(proxy: dict, index):
     """
     检验代理连通性函数
 
+    :param index:
     :param proxy: 代理IP信息
     :return:
     """
@@ -127,43 +126,43 @@ def server(index=None, limit=5, console=False, sync=True):
 
     if sync:
         results[index] = [connect(proxy) for proxy in _hosts]
-        results[index] = [x for x in results[index] if x.get("time")]
+        results[index] = [x for x in results[index] if x.get('time')]
     else:
         async_event()
 
-    server = results[index]
+    servers = results[index]
 
     # 结果按响应时间从小到大排序
     if console:
         from prettytable import PrettyTable
 
-        server.sort(key=lambda item: item["time"])
+        servers.sort(key=lambda item: item['time'])
 
         if limit:
-            server = server[:limit]
+            servers = servers[:limit]
 
-        logger.debug("[√] 最优服务器:")
+        logger.debug('[√] 最优服务器:')
 
-        t = PrettyTable(["Name", "Addr", "Port", "Time"])
-        t.align["Name"] = "l"
-        t.align["Addr"] = "l"
-        t.align["Port"] = "l"
-        t.align["Time"] = "r"
+        t = PrettyTable(['Name', 'Addr', 'Port', 'Time'])
+        t.align['Name'] = 'l'
+        t.align['Addr'] = 'l'
+        t.align['Port'] = 'l'
+        t.align['Time'] = 'r'
         t.padding_width = 1
 
-        for host in server:
+        for host in servers:
             t.add_row(
                 [
-                    host["site"],
-                    host["addr"],
-                    host["port"],
-                    "{:5.2f} ms".format(host["time"]),
+                    host['site'],
+                    host['addr'],
+                    host['port'],
+                    '{:5.2f} ms'.format(host['time']),
                 ]
             )
 
-        logger.debug("\n" + str(t))
+        logger.debug('\n' + str(t))
 
-    return [(item["addr"], int(item["port"])) for item in server]
+    return [(item['addr'], int(item['port'])) for item in servers]
 
 
 def check_server(console=False, limit=5, sync=False) -> None:
@@ -171,24 +170,24 @@ def check_server(console=False, limit=5, sync=False) -> None:
 
 
 def bestip(console=False, limit=5, sync=False) -> None:
-    config_ = get_config_path("config.json")
+    config_ = get_config_path('config.json')
     default = dict(CONFIG)
 
-    logger.info("[-] 选择最快的服务器...")
+    logger.info('[-] 选择最快的服务器...')
     logger.debug(f'sync => {sync}')
 
-    for index in ["HQ", "EX", "GP"]:
+    for index in ['HQ', 'EX', 'GP']:
         try:
             data = server(index=index, limit=limit, console=console, sync=sync)
 
             if data:
-                default["BESTIP"][index] = data[0]
-        except RuntimeError as ex:
-            logger.error("请手动运行`python -m mootdx bestip`")
+                default['BESTIP'][index] = data[0]
+        except RuntimeError:
+            logger.error('请手动运行`python -m mootdx bestip`')
             break
 
-    json.dump(default, open(config_, "w", encoding="utf-8"), indent=2, ensure_ascii=False)
+    json.dump(default, open(config_, 'w', encoding='utf-8'), indent=2, ensure_ascii=False)
 
 
-if __name__ == "__main__":
+if __name__ == '__main__':
     bestip(sync=False, limit=5, console=True)
